@@ -1,18 +1,24 @@
 #' @title Tabla de frecuencia de palabras tokenizadas.
-#' @description Función que cuenta la frecuencia de palabras tokenizadas.
+#' @description Funcion que cuenta la frecuencia de palabras tokenizadas.
 #' @param x vector de palabras tokenizadas.
-#' @param u numero de corte para el top de palabras más frecuentes.
+#' @param u numero de corte para el top de palabras mas frecuentes.
 #' @export acep_token_table
 #' @return Si todas las entradas son correctas,
-#' la salida será una tabla con la frecuencia relativa y
+#' la salida sera una tabla con la frecuencia relativa y
 #' absoluta de palabras tokenizadas.
 #' @keywords tablas
 #' @examples
-#' rev_puerto <- acep_clean(acep_bases$rev_puerto$titulo)
-#' rev_puerto_token <- acep_token(rev_puerto)
-#' acep_token_table(rev_puerto_token$token)
+#' tokens <- c(rep("paro",15), rep("piquete",25), rep("corte",20), rep("manifestacion",10),
+#' rep("bloqueo",5), rep("alerta",16), rep("ciudad",12), rep("sindicato",11), rep("paritaria",14),
+#' rep("huelga",14), rep("escrache",15))
+#' acep_token_table(tokens)
 #' @export
 acep_token_table <- function(x, u = 10) {
+  if(is.vector(x) != TRUE){
+    message("No ingresaste un vector en el parametro x. Vuelve a intentarlo ingresando un vector!")
+  } else {
+    if(is.vector(x) == TRUE) {
+      tryCatch({
   tabla_token <- base::table(x) |> as.data.frame()
   tabla_token <- tabla_token[order(tabla_token$Freq, decreasing = TRUE), ]
   tabla_token <- utils::head(tabla_token, n = u)
@@ -22,4 +28,8 @@ acep_token_table <- function(x, u = 10) {
     frec = tabla_token$Freq,
     prop = tabla_token$prop)
   utils::head(tabla_token, n = u)
+      }
+      )
+    }
+  }
 }
